# tron

> **WARNING:** this version is Python 3 only in preparation for SDSS-V. For SDSS-IV, use the ``python2`` branch.

Central communications hub for operations software processes. Manages the flow of command and reply messages and authenticates users. The product itself is called "tron".
